.. _changes:

Changes in Swingtime
====================

Release 0.6 (April 5, 2015)
---------------------------

* Added ``bulk_create`` in ``Event.add_occurrences`` (siolag161)
* Support for Django 1.8
* Added tests and docs

Release 0.5 (February 11, 2015)
-------------------------------

* Added `tox`, `Travis CI`, a separate `tests` project, and `MANIFEST.in`
* Cleaned up demo project, docs, `setup.py`
* Removed support for Django<1.6

Release 0.4.1 (February 10, 2015)
---------------------------------

* Bugfix for form `rrule`

Release 0.4 (September 18, 2014)
--------------------------------

* Added support for Python 3.4

Release 0.3.3 (September 17, 2014)
----------------------------------

* Added support for Django 1.5, 1.6, 1.7

Release 0.2.2 (March 16, 2013)
------------------------------

* Registered in PyPI
* Installs with `pip`

Release 0.2 (Decemeber 18, 2008)
--------------------------------

* First public release.